/**
 * eobjects.org MetaModel
 * Copyright (C) 2010 eobjects.org
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.eobjects.metamodel.create;

import org.eobjects.metamodel.MetaModelException;
import org.eobjects.metamodel.schema.Column;
import org.eobjects.metamodel.schema.ColumnType;
import org.eobjects.metamodel.schema.MutableColumn;
import org.eobjects.metamodel.schema.Table;

/**
 * Implementation of the {@link ColumnCreationBuilder}.
 * 
 * @author Kasper Sørensen
 */
final class ColumnCreationBuilderImpl implements ColumnCreationBuilder {

    private final TableCreationBuilder _createTableBuilder;
    private final MutableColumn _column;

    public ColumnCreationBuilderImpl(TableCreationBuilder createTableBuilder, MutableColumn column) {
        _createTableBuilder = createTableBuilder;
        _column = column;
    }

    @Override
    public String toSql() {
        return _createTableBuilder.toSql();
    }

    @Override
    public ColumnCreationBuilder like(Column column) {
        _column.setColumnSize(column.getColumnSize());
        _column.setNativeType(column.getNativeType());
        _column.setType(column.getType());
        _column.setNullable(column.isNullable());
        return this;
    }

    @Override
    public ColumnCreationBuilder ofType(ColumnType type) {
        _column.setType(type);
        return this;
    }

    @Override
    public ColumnCreationBuilder ofNativeType(String nativeType) {
        _column.setNativeType(nativeType);
        return this;
    }

    @Override
    public ColumnCreationBuilder ofSize(int size) {
        _column.setColumnSize(size);
        return this;
    }

    @Override
    public ColumnCreationBuilder nullable(boolean nullable) {
        _column.setNullable(nullable);
        return this;
    }

    @Override
    public TableCreationBuilder like(Table table) {
        return _createTableBuilder.like(table);
    }

    @Override
    public Table execute() throws MetaModelException {
        return _createTableBuilder.execute();
    }

    @Override
    public ColumnCreationBuilder withColumn(String name) {
        return _createTableBuilder.withColumn(name);
    }
    
    @Override
    public ColumnCreationBuilder asPrimaryKey() {
        _column.setPrimaryKey(true);
        return this;
    }

    @Override
    public Table toTable() {
        return _createTableBuilder.toTable();
    }
}
